@@ -7,4 +7,5 @@ register = template.Library()
 @register.assignment_tag
 def get_new_notifications_count(user):
     """Usually used to display an unread notifications counter"""
-    return user.notifications.filter(displayed=False).count()
+    from notifications.models import Notification
+    return user.notifications.exclude(noti_type=Notification.EMAIL_NOTI).filter(displayed=False).count()
